/*
    Adapted for jupyter-themer from https://github.com/codemirror
*/

/* Port of TextMate's Blackboard theme */

.CodeMirror { background: #0C1021; color: #F8F8F8; }
.CodeMirror div.CodeMirror-selected { background: #253B76; }
.CodeMirror .CodeMirror-line::selection, .CodeMirror .CodeMirror-line > span::selection, .CodeMirror .CodeMirror-line > span > span::selection { background: rgba(37, 59, 118, .99); }
.CodeMirror .CodeMirror-line::-moz-selection, .CodeMirror .CodeMirror-line > span::-moz-selection, .CodeMirror .CodeMirror-line > span > span::-moz-selection { background: rgba(37, 59, 118, .99); }
.CodeMirror .CodeMirror-gutters { background: #0C1021; border-right: 0; }
.CodeMirror .CodeMirror-guttermarker { color: #FBDE2D; }
.CodeMirror .CodeMirror-guttermarker-subtle { color: #888; }
.CodeMirror .CodeMirror-linenumber { color: #888; }
.CodeMirror .CodeMirror-cursor { border-left: 1px solid #A7A7A7; }

.CodeMirror .cm-keyword { color: #FBDE2D; }
.CodeMirror .cm-atom { color: #D8FA3C; }
.CodeMirror .cm-number { color: #D8FA3C; }
.CodeMirror .cm-def { color: #8DA6CE; }
.CodeMirror .cm-variable { color: #FF6400; }
.CodeMirror .cm-operator { color: #FBDE2D; }
.CodeMirror .cm-comment { color: #AEAEAE; }
.CodeMirror .cm-string { color: #61CE3C; }
.CodeMirror .cm-string-2 { color: #61CE3C; }
.CodeMirror .cm-meta { color: #D8FA3C; }
.CodeMirror .cm-builtin { color: #8DA6CE; }
.CodeMirror .cm-tag { color: #8DA6CE; }
.CodeMirror .cm-attribute { color: #8DA6CE; }
.CodeMirror .cm-header { color: #FF6400; }
.CodeMirror .cm-hr { color: #AEAEAE; }
.CodeMirror .cm-link { color: #8DA6CE; }
.CodeMirror .cm-error { background: #9D1E15; color: #F8F8F8; }

.CodeMirror .CodeMirror-activeline-background { background: #3C3636; }
.CodeMirror .CodeMirror-matchingbracket { outline:1px solid grey;color:white !important; }
